#
# New BSD License
# ===============
# Copyright (c) 2007, Graham Binns http://launchpad.net/~gmb
#
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in
#       the documentation and/or other materials provided with the
#       distribution.
#
#     * Neither the name of the <ORGANIZATION> nor the names of its
#       contributors may be used to endorse or promote products derived
#       from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
# IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
# OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

"""Blog post manipulation module for the clog application"""

__metaclass__ = type

__all__ = ['BlogPost']

from datetime import datetime
import email

class BlogPost(object):
    """An object representing a blog post."""

    def __init__(self, subject=None, categories=None, body=None):
        self.subject = subject
        self.body = body

        if categories is None:
            self.categories = []
        else:
            self.categories = categories

    @classmethod
    def fromText(cls, post_text):
        """Return a BlogPost parsed from an RFC822 compliant message."""
        # The messages that clog expects are RFC822 compliant, so we
        # can use the email module to parse them.
        post_data = email.message_from_string(post_text)

        post = BlogPost(subject=post_data.get('subject'),
            body=post_data.get_payload())

        if 'categories' in post_data:
            categories = [category.strip() for category in
                post_data['categories'].split(',')]
            post.categories = categories

        return post

    def toMetaWeblogStruct(self):
        """Return a MetaWeblog Post struct of the current Post's data."""
        struct = {
            'title': self.subject,
            'description': self.body,
            'pubDate': str(datetime.now()),
            'category': self.categories,
        }

        return struct
