# New BSD License
# ===============
# Copyright (c) 2007, Graham Binns http://launchpad.net/~gmb
#
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
#     * Redistributions of source code must retain the above copyright
#       notice, this list of conditions and the following disclaimer.
#
#     * Redistributions in binary form must reproduce the above copyright
#       notice, this list of conditions and the following disclaimer in
#       the documentation and/or other materials provided with the
#       distribution.
#
#     * Neither the name of the <ORGANIZATION> nor the names of its
#       contributors may be used to endorse or promote products derived
#       from this software without specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS
# IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED
# TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER
# OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
# EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
# PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
# PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
# LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
# NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

"""Metaweblog functionality for the clog app."""

__metaclass__ = type

__all__ = ['MetaWeblog']

from xmlrpclib import Fault, ServerProxy

class MetaWeblog:
    """A MetaWeblog API implementation for a single blog."""

    def __init__(self, url, blog, username, password):
        self.url = url
        self.blog = blog
        self.username = username
        self.password = password

        # Create the ServerProxy that we'll use to pass XMLRPC requests
        # back and forth.
        self.server_proxy = ServerProxy(url)

    def getRecentPosts(self):
        """Get the recent posts for the current user on the current blog."""
        return self.server_proxy.metaWeblog.getRecentPosts(
            self.blog, self.username, self.password)

    def editPost(self, post_id, new_post):
        """Update an existing MetaWeblog post with new post data."""

    def newPost(self, struct, publish=False):
        """Create a new post on a remote blog."""
        return self.server_proxy.metaWeblog.newPost(self.blog,
            self.username, self.password, struct, publish)
